@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-1997, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2009, Live Networks, Inc.  All rights reserved
 // "Group Endpoint Id"
 // Implementation
 
@@ -44,20 +44,23 @@ Scope::Scope(const Scope& orig) {
 }
 
 Scope& Scope::operator=(const Scope& rightSide) {
-  if (publicKey() == NULL
-      || strcmp(publicKey(), rightSide.publicKey()) != 0) {
-    clean();
-    assign(rightSide.ttl(), rightSide.publicKey());
-  } else { // need to assign TTL only
-    fTTL = rightSide.ttl();
+  if (&rightSide != this) {
+    if (publicKey() == NULL
+	|| strcmp(publicKey(), rightSide.publicKey()) != 0) {
+      clean();
+      assign(rightSide.ttl(), rightSide.publicKey());
+    } else { // need to assign TTL only
+      fTTL = rightSide.ttl();
+    }
   }
+
   return *this;
 }
 
 Scope::~Scope() {
   clean();
 }
-	
+
 unsigned Scope::publicKeySize() const {
   return fPublicKey == NULL ? 0 : strlen(fPublicKey);
 }
